Documentation
¶
Index ¶
- Variables
- func AppendNoDuplicates(list []map[string]interface{}, item map[string]interface{}) []map[string]interface{}
- func ContextWithRelationships(ctx context.Context, typeDescriptors []*descriptor.TypeDescriptor, ...) context.Context
- func GetColumnNameAndTypeFromQueryParameterName(typeDescriptors []*descriptor.TypeDescriptor, tableName string, ...) (columnName, columnType string, ok bool)
- func GetDBTableNameUsingTypeDescriptorKey(typeDescriptors []*descriptor.TypeDescriptor, typeDescriptorKey string) (tableName string, ok bool)
- func GetTypeDescriptorUsingDBTableName(typeDescriptors []*descriptor.TypeDescriptor, tableName string) (td *descriptor.TypeDescriptor)
- func GetTypeDescriptorUsingTypeDescriptorKey(typeDescriptors []*descriptor.TypeDescriptor, typeDescriptorKey string) (result *descriptor.TypeDescriptor)
- func IsOptionRoute(req *http.Request) bool
- func IsOptionsRoute(req *http.Request) bool
- func ParseDataForm(req *http.Request) (data map[string]interface{}, err error)
- func TableHasRelationships(cfg config.Config, table string) bool
- func TypeDescriptorRelationships(td *descriptor.TypeDescriptor) []*descriptor.Field
- type ContextKey
- type NullTime
- type ResponseMessage
Constants ¶
This section is empty.
Variables ¶
var ( ErrCardinalityMany = errors.New("Form data contained multiple input values for a single column") ErrUnexpectedJSON = errors.New("Received JSON data that we are unable to parse") )
Functions ¶
func AppendNoDuplicates ¶
func ContextWithRelationships ¶
func ContextWithRelationships(ctx context.Context, typeDescriptors []*descriptor.TypeDescriptor, table string) context.Context
ContextWithRelationships will return a new context which will included an array of all relationships for the table provided in the function's second parameter
func GetColumnNameAndTypeFromQueryParameterName ¶
func GetColumnNameAndTypeFromQueryParameterName(typeDescriptors []*descriptor.TypeDescriptor, tableName string, paramName string) (columnName, columnType string, ok bool)
func GetDBTableNameUsingTypeDescriptorKey ¶
func GetDBTableNameUsingTypeDescriptorKey(typeDescriptors []*descriptor.TypeDescriptor, typeDescriptorKey string) (tableName string, ok bool)
GetDBTableNameUsingTypeDescriptorKey will return the typeDescriptor from the descriptor.json file defined for the table provided in the function's second parameter
func GetTypeDescriptorUsingDBTableName ¶
func GetTypeDescriptorUsingDBTableName(typeDescriptors []*descriptor.TypeDescriptor, tableName string) (td *descriptor.TypeDescriptor)
GetTypeDescriptorUsingDBTableName will return the typeDescriptor from the descriptor.json file defined for the table provided in the function's second parameter
func GetTypeDescriptorUsingTypeDescriptorKey ¶
func GetTypeDescriptorUsingTypeDescriptorKey(typeDescriptors []*descriptor.TypeDescriptor, typeDescriptorKey string) (result *descriptor.TypeDescriptor)
func IsOptionRoute ¶
func IsOptionsRoute ¶
func TypeDescriptorRelationships ¶
func TypeDescriptorRelationships(td *descriptor.TypeDescriptor) []*descriptor.Field
Types ¶
type ContextKey ¶
type ContextKey string
ContextKey is used as a key when populating a context.Context with values
type ResponseMessage ¶
func (*ResponseMessage) Byte ¶
func (rm *ResponseMessage) Byte() []byte
func (*ResponseMessage) Error ¶
func (rm *ResponseMessage) Error() string
func (*ResponseMessage) String ¶
func (rm *ResponseMessage) String() string
Click to show internal directories.
Click to hide internal directories.